@@ -60,22 +60,40 @@ def check_tests():
 def increment_changes():
     """increment changes"""
     version = get_version()
-    CHANGES = os.path.join(os.getcwd(), 'CHANGES')
-    if not os.path.exists(CHANGES):
-        # no CHANGES file, let's create it
-        content = ['* trunk',
-                   '  - ',
-                   '',
-                   '* %s' % version,
-                   '  - initial revision']
-    else:
+    if os.path.exists(os.path.join(os.getcwd(), 'CHANGES.txt')):
+        # FIXME: Plone's CHANGES.txt (need to become a standard)
+        CHANGES = os.path.join(os.getcwd(), 'CHANGES.txt')
         # raising the version
         content = open(CHANGES).read()
-        if '* %s' % version not in content:
-            content = content.replace('* trunk', '* %s' % version)
-            content = ['* trunk',  '  -'] + content.split('\n')
+        if '%s (20' % version not in content:
+            content = content.replace('trunk (20', '%s (20' % version)
+            now = datetime.datetime.now().strftime('%Y-')
+            content = ['trunk (%sxx-xx)' % now,
+                       '==================',
+                       '',
+                       '  - xxx [Ingeniweb]',
+                       ''] + content.split('\n')
         else:
             content = content.split('\n')
+    else:
+        # FIXME: IW CHANGES (need to use the Plone standard instead)
+        CHANGES = os.path.join(os.getcwd(), 'CHANGES')
+        if not os.path.exists(CHANGES):
+            # no CHANGES file, let's create it
+            content = ['* trunk',
+                       '  - ',
+                       '',
+                       '* %s' % version,
+                       '  - initial revision',
+                       '']
+        else:
+            # raising the version
+            content = open(CHANGES).read()
+            if '* %s' % version not in content:
+                content = content.replace('* trunk', '* %s' % version)
+                content = ['* trunk',  '  -'] + content.split('\n')
+            else:
+                content = content.split('\n')
     f = open(CHANGES, 'w')
     try:
         f.write('\n'.join(content))
@@ -139,6 +157,7 @@ def _run_setup(*args):
     old_args = sys.argv
     sys.argv = [sys.argv[0] + 'setup.py'] + list(args)
     __import__('setup')
+    del sys.modules['setup']
     sys.argv = old_args
 
 def pypi_upload():
